@@ -4,7 +4,7 @@ use warnings;
 use autodie;
 package CPAN::Meta::Converter;
 BEGIN {
-  $CPAN::Meta::Converter::VERSION = '2.101610';
+  $CPAN::Meta::Converter::VERSION = '2.102160';
 }
 # ABSTRACT: Convert CPAN distribution metadata structures
 
@@ -542,12 +542,13 @@ my $resource2_upgrade = {
   license    => sub { return _is_urlish($_[0]) ? _listify( $_[0] ) : undef },
   homepage   => \&_url_or_drop,
   bugtracker => sub {
-    my $item = @_;
+    my ($item) = @_;
+    return unless $item;
     if ( $item =~ m{^mailto:(.*)$} ) { return { mailto => $1 } }
-    elsif( _is_urlish($item) ) { return { web => $_[0] } }
+    elsif( _is_urlish($item) ) { return { web => $item } }
     else { return undef }
   },
-  repository => sub { return _is_urlish($_[0]) ? { web => $_[0] } : undef },
+  repository => sub { return _is_urlish($_[0]) ? { url => $_[0] } : undef },
   ':custom'  => \&_prefix_custom,
 };
 
@@ -1242,7 +1243,7 @@ CPAN::Meta::Converter - Convert CPAN distribution metadata structures
 
 =head1 VERSION
 
-version 2.101610
+version 2.102160
 
 =head1 SYNOPSIS
 
